'use strict';

const autoprefixer = require('autoprefixer');
const path = require('path');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const InterpolateHtmlPlugin = require('react-dev-utils/InterpolateHtmlPlugin');

const paths = require('./paths');
const SCRIPT_NAME = 'sissi-script.js';
const STYLES_NAME = 'styles.css';

const publicPath = paths.servedPath;
const publicUrl = publicPath.slice(0, -1);

module.exports = {
  bail: true,
  devtool: false,
  entry: [paths.appIndexJs],
  output: {
    path: paths.appBuild,
    filename: SCRIPT_NAME,
    publicPath: publicPath,
    library: 'Page',
    libraryTarget: 'umd'
  },
  resolve: {
    extensions: ['.js', '.json', '.jsx']
  },
  module: {
    strictExportPresence: true,
    rules: [{
      oneOf: [{
        test: [/\.bmp$/, /\.gif$/, /\.jpe?g$/, /\.png$/],
        loader: require.resolve('url-loader'),
        options: {
          limit: 10000,
          name: 'static/assets/[name].[ext]'
        }
      }, {
        test: /\.(js|jsx)$/,
        exclude: [/[/\\\\]node_modules[/\\\\]/],
        use: [{
          loader: require.resolve('babel-loader'),
          options: {
            presets: [require.resolve('babel-preset-react-app')],
            compact: true,
            highlightCode: true
          }
        }]
      }, {
        test: /\.scss$/,
        loader: ExtractTextPlugin.extract(Object.assign({
          fallback: {
            loader: require.resolve('style-loader'),
            options: {
              hmr: false
            }
          },
          use: [{
            loader: require.resolve('css-loader'),
            options: {
              importLoaders: 1,
              minimize: true,
              sourceMap: false
            }
          }, {
            loader: require.resolve('postcss-loader'),
            options: {
              ident: 'postcss',
              plugins: () => [require('postcss-flexbugs-fixes'), autoprefixer({
                browsers: ['last 2 versions', 'IE >= 11', 'Firefox ESR'],
                flexbox: 'no-2009'
              })]
            }
          }, {
            loader: require.resolve('sass-loader'),
            options: {
              precision: 8
            }
          }]
        }))
      }, {
        loader: require.resolve('file-loader'),
        exclude: [/\.(js|jsx|mjs)$/, /\.html$/, /\.json$/],
        options: {
          name: 'static/assets/[name].[ext]'
        }
      }]
    }]
  },
  plugins: [new HtmlWebpackPlugin({
    inject: true,
    template: paths.appHtml,
    minify: {
      removeComments: true,
      collapseWhitespace: true,
      removeRedundantAttributes: true,
      useShortDoctype: true,
      removeEmptyAttributes: true,
      removeStyleLinkTypeAttributes: true,
      keepClosingSlash: true,
      minifyJS: true,
      minifyCSS: true,
      minifyURLs: true
    }
  }), new InterpolateHtmlPlugin({ PUBLIC_URL: publicUrl }), new ExtractTextPlugin({
    filename: STYLES_NAME
  })],
  node: {
    dgram: 'empty',
    fs: 'empty',
    net: 'empty',
    tls: 'empty',
    child_process: 'empty'
  },
  performance: false
};