'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _require = require('child_process');

const execFile = _require.execFile;

const webpack = require('webpack');
const WebpackDevServer = require('webpack-dev-server');

var _require2 = require('react-dev-utils/WebpackDevServerUtils');

const choosePort = _require2.choosePort,
      createCompiler = _require2.createCompiler,
      prepareUrls = _require2.prepareUrls;

const openBrowser = require('react-dev-utils/openBrowser');

const paths = require('./config/paths');
const config = require('./config/webpack.config.dev');
const createDevServerConfig = require('./config/webpackDevServer.config');

const protocol = 'http';
const host = '0.0.0.0';

exports.default = async function dev(defaultPort) {

  try {
    const port = await choosePort(host, defaultPort);
    const urls = prepareUrls(protocol, host, port);

    const compiler = webpack(config);
    const serverConfig = createDevServerConfig(host);
    const devServer = new WebpackDevServer(compiler, serverConfig);

    devServer.listen(port, host, err => {
      if (err) {
        return console.log(err);
      }
      console.log(`Development server listening on port ${port}...`);
      openBrowser(urls.localUrlForBrowser);
    });

    ['SIGINT', 'SIGTERM'].forEach(sig => {
      process.on(sig, () => {
        devServer.close();
        process.exit();
      });
    });
  } catch (err) {
    if (err && err.message) {
      console.log(err);
      console.log(err.message);
    }
    process.exit(1);
  }
};